<?php

namespace Drupal\simple_redirect;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Path\PathValidatorInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class SimpleRedirectManager.
 *
 * @package Drupal\simple_redirect
 */
class SimpleRedirectManager implements SimpleRedirectManagerInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The path validator.
   *
   * @var \Drupal\Core\Path\PathValidatorInterface
   */
  protected $pathValidator;

  /**
   * Constructs a new SimpleRedirectManager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\Core\Path\PathValidatorInterface $path_validator
   *   The path validator service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RequestStack $request_stack, PathValidatorInterface $path_validator) {
    $this->configFactory = $config_factory;
    $this->requestStack = $request_stack;
    $this->pathValidator = $path_validator;
  }

  /**
   * {@inheritdoc}
   */
  public function simpleRedirect() {
    $toUrl = '<front>';
    $config = $this->configFactory->get('simple_redirect.settings');
    $request = $this->requestStack->getCurrentRequest()->request;
    if ($request->get('form_id') == 'user_login_form' && !empty($config->get('user_login'))) {
      $toUrl = $config->get('user_login');
    }
    if ($request->get('form_id') == 'user_register_form' && !empty($config->get('user_register'))) {
      $toUrl = $config->get('user_register');
    }
    // To check the current user is having permission to view the redirecting page.
    $url = $this->pathValidator->getUrlIfValid($toUrl);
    if ($url == FALSE) {
      drupal_set_message(t('You will not be redirected to ":toUrl" page, you donot have permission to view this page.',
        array(':toUrl' => $toUrl)
      ));
      throw new AccessDeniedHttpException();
    }

    $url->setAbsolute();
    $redirect = $url->toString();
    return (new RedirectResponse($redirect))->send();
  }

}
